@@ -276,6 +276,10 @@ static PyObject *pyBwGetHeader(pyBigWigFile_t *self, PyObject *args) {
         PyErr_SetString(PyExc_RuntimeError, "The bigWig file handle is not opened!");
         return NULL;
     }
+    if(bw->isWrite == 1) {
+        PyErr_SetString(PyExc_RuntimeError, "The header cannot be accessed in files opened for writing!");
+        return NULL;
+    }
 
     ret = PyDict_New();
     val = PyLong_FromUnsignedLong(bw->hdr->version);
@@ -321,6 +325,11 @@ static PyObject *pyBwGetChroms(pyBigWigFile_t *self, PyObject *args) {
         return NULL;
     }
 
+    if(bw->isWrite == 1) {
+        PyErr_SetString(PyExc_RuntimeError, "Chromosomes cannot be accessed in files opened for writing!");
+        return NULL;
+    }
+
     if(!(PyArg_ParseTuple(args, "|s", &chrom)) || !chrom) {
         ret = PyDict_New();
         for(i=0; i<bw->cl->nKeys; i++) {
@@ -380,6 +389,11 @@ static PyObject *pyBwGetStats(pyBigWigFile_t *self, PyObject *args, PyObject *kw
         return NULL;
     }
 
+    if(bw->isWrite == 1) {
+        PyErr_SetString(PyExc_RuntimeError, "Statistics cannot be accessed in files opened for writing!");
+        return NULL;
+    }
+
     if(bw->type == 1) {
         PyErr_SetString(PyExc_RuntimeError, "bigBed files have no statistics!");
         return NULL;
@@ -621,6 +635,11 @@ static PyObject *pyBwGetIntervals(pyBigWigFile_t *self, PyObject *args, PyObject
         return NULL;
     }
 
+    if(bw->isWrite == 1) {
+        PyErr_SetString(PyExc_RuntimeError, "Intervals cannot be accessed in files opened for writing!");
+        return NULL;
+    }
+
     if(bw->type == 1) {
         PyErr_SetString(PyExc_RuntimeError, "bigBed files have no intervals! Use 'entries()' instead.");
         return NULL;
@@ -724,7 +743,7 @@ int PyString_Check(PyObject *obj) {
 
 //I don't know what happens if PyBytes_AsString(NULL) is used...
 char *PyString_AsString(PyObject *obj) {
-    return PyBytes_AsString(PyUnicode_AsASCIIString(obj));
+    return PyUnicode_AsUTF8(obj);
 }
 #endif
 
